2
0

Stream thread-safe checkpoint.

Moving data structures to critical / protected section.


[ROCm/hip commit: 3f18bab2c7]
Este cometimento está contido em:
Ben Sander
2016-03-28 09:46:40 -05:00
ascendente 0f11beb328
cometimento 9e3ac64c54
5 ficheiros modificados com 171 adições e 129 eliminações
+3 -3
Ver ficheiro
@@ -82,7 +82,7 @@ hipError_t hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int
// TODO-hcc Convert to use create_blocking_marker(...) functionality.
// Currently we have a super-conservative version of this - block on host, and drain the queue.
// This should create a barrier packet in the target queue.
stream->wait();
stream->locked_wait();
e = hipSuccess;
}
@@ -101,7 +101,7 @@ hipError_t hipStreamSynchronize(hipStream_t stream)
ihipDevice_t *device = ihipGetTlsDefaultDevice();
device->locked_syncDefaultStream(true/*waitOnSelf*/);
} else {
stream->wait();
stream->locked_wait();
e = hipSuccess;
}
@@ -125,7 +125,7 @@ hipError_t hipStreamDestroy(hipStream_t stream)
ihipDevice_t *device = ihipGetTlsDefaultDevice();
device->locked_syncDefaultStream(true/*waitOnSelf*/);
} else {
stream->wait();
stream->locked_wait();
e = hipSuccess;
}